@@ -75,11 +75,19 @@ class PaymentCreator:
                 )
 
             # Get provider for payment creation
-            provider = self.provider_registry.get_provider(request.provider)
+            # If provider not specified, use primary provider
+            if request.provider:
+                provider = self.provider_registry.get_provider(request.provider)
+                provider_name = request.provider
+            else:
+                provider = self.provider_registry.get_primary_provider()
+                provider_name = provider.name if provider else None
+
             if not provider:
+                error_msg = f"Provider {provider_name} not available" if provider_name else "No payment provider available"
                 return PaymentResult(
                     success=False,
-                    message=f"Provider {request.provider} not available",
+                    message=error_msg,
                     error_code="provider_not_available"
                 )
 
@@ -91,12 +99,12 @@ class PaymentCreator:
                     amount_usd=request.amount_usd,
                     currency=currency,
                     network=currency.native_networks.first(),  # Use first native network
-                    provider=request.provider,
+                    provider=provider_name,
                     status=UniversalPayment.PaymentStatus.PENDING,
                     status_changed_at=timezone.now(),  # Track initial status setting
-                    callback_url=request.callback_url,
-                    cancel_url=request.cancel_url,
-                    description=request.description,
+                    callback_url=request.callback_url or '',
+                    cancel_url=request.cancel_url or '',
+                    description=request.description or '',
                     expires_at=timezone.now() + timezone.timedelta(hours=1)  # 1 hour expiry
                 )
                 return payment
@@ -106,12 +114,9 @@ class PaymentCreator:
             # Create payment with provider
             from ...providers.models import PaymentRequest as ProviderPaymentRequest
 
-            # Use provider_currency_code from metadata if available, otherwise use original currency_code
-            provider_currency_code = request.metadata.get('provider_currency_code', request.currency_code)
-
             provider_request = ProviderPaymentRequest(
                 amount_usd=request.amount_usd,
-                currency_code=provider_currency_code,  # Use provider-specific currency code
+                currency_code=request.currency_code,
                 order_id=str(payment.id),
                 callback_url=request.callback_url,
                 cancel_url=request.cancel_url,
