@@ -49,6 +49,15 @@ class ProviderEnum(Enum):
             if PROVIDER_METADATA[provider.value].status == ProviderStatus.ACTIVE
         ]
 
+    @classmethod
+    def get_priority_order(cls) -> List[str]:
+        """Get providers ordered by priority (highest first)."""
+        providers_with_priority = [
+            (provider.value, PROVIDER_METADATA[provider.value].priority)
+            for provider in cls
+        ]
+        return [p[0] for p in sorted(providers_with_priority, key=lambda x: x[1], reverse=True)]
+
 
 # Provider metadata registry
 PROVIDER_METADATA: Dict[str, ProviderMetadata] = {
