@@ -26,7 +26,10 @@ class PaymentCreateRequest(BaseModel):
     currency_code: str = Field(
         min_length=2, max_length=10, description="Cryptocurrency code"
     )
-    provider: Literal['nowpayments'] = Field(default='nowpayments', description="Payment provider")
+    provider: Optional[Literal['nowpayments']] = Field(
+        None,
+        description="Payment provider (auto-selected if not specified)"
+    )
     callback_url: Optional[str] = Field(None, description="Success callback URL")
     cancel_url: Optional[str] = Field(None, description="Cancellation URL")
     description: Optional[str] = Field(None, max_length=500, description="Payment description")
