@@ -4,25 +4,24 @@ Balance ViewSets for the Universal Payment System v2.0.
 DRF ViewSets for balance and transaction management with service integration.
 """
 
-from rest_framework import viewsets, permissions, status
-from rest_framework.decorators import action
-from rest_framework.response import Response
-from django_filters.rest_framework import DjangoFilterBackend
 from django.contrib.auth import get_user_model
 from django.db import models
 from django.utils import timezone
+from rest_framework import permissions, status
+from rest_framework.decorators import action
+from rest_framework.response import Response
 
-from .base import PaymentBaseViewSet, NestedPaymentViewSet, ReadOnlyPaymentViewSet
-from ...models import UserBalance, Transaction
-from ...services import get_balance_service
+from django_cfg.modules.django_logging import get_logger
+
+from ...models import Transaction, UserBalance
 from ..serializers.balances import (
-    UserBalanceSerializer,
-    TransactionSerializer,
+    BalanceStatsSerializer,
     BalanceUpdateSerializer,
     FundsTransferSerializer,
-    BalanceStatsSerializer,
+    TransactionSerializer,
+    UserBalanceSerializer,
 )
-from django_cfg.modules.django_logging import get_logger
+from .base import NestedPaymentViewSet, ReadOnlyPaymentViewSet
 
 User = get_user_model()
 logger = get_logger("balance_viewsets")
@@ -34,24 +33,24 @@ class UserBalanceViewSet(ReadOnlyPaymentViewSet):
     
     Read-only access to user balances with statistics.
     """
-    
+
     queryset = UserBalance.objects.all()
     serializer_class = UserBalanceSerializer
     permission_classes = [permissions.IsAuthenticated]
     filterset_fields = ['user']
     search_fields = ['user__username', 'user__email']
     ordering_fields = ['balance_usd', 'created_at', 'updated_at']
-    
+
     def get_queryset(self):
         """Filter by user permissions and optimize queryset."""
         queryset = super().get_queryset().select_related('user')
-        
+
         # Non-staff users can only see their own balance
         if not self.request.user.is_staff:
             queryset = queryset.filter(user=self.request.user)
-        
+
         return queryset
-    
+
     @action(detail=True, methods=['post'])
     def add_funds(self, request, pk=None):
         """
@@ -60,14 +59,14 @@ class UserBalanceViewSet(ReadOnlyPaymentViewSet):
         POST /api/balances/{id}/add_funds/
         """
         balance = self.get_object()
-        
+
         # Permission check: users can only add funds to their own balance
         if not request.user.is_staff and balance.user != request.user:
             return Response(
                 {'error': 'You can only add funds to your own balance'},
                 status=status.HTTP_403_FORBIDDEN
             )
-        
+
         serializer = BalanceUpdateSerializer(
             data=request.data,
             context={
@@ -75,13 +74,13 @@ class UserBalanceViewSet(ReadOnlyPaymentViewSet):
                 'user_pk': balance.user.id
             }
         )
-        
+
         if serializer.is_valid():
             result = serializer.save()
             return Response(result)
-        
+
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
-    
+
     @action(detail=True, methods=['post'])
     def withdraw_funds(self, request, pk=None):
         """
@@ -90,19 +89,19 @@ class UserBalanceViewSet(ReadOnlyPaymentViewSet):
         POST /api/balances/{id}/withdraw_funds/
         """
         balance = self.get_object()
-        
+
         # Permission check
         if not request.user.is_staff and balance.user != request.user:
             return Response(
                 {'error': 'You can only withdraw from your own balance'},
                 status=status.HTTP_403_FORBIDDEN
             )
-        
+
         # Convert to negative amount for withdrawal
         data = request.data.copy()
         if 'amount' in data and data['amount'] > 0:
             data['amount'] = -abs(data['amount'])
-        
+
         serializer = BalanceUpdateSerializer(
             data=data,
             context={
@@ -110,13 +109,13 @@ class UserBalanceViewSet(ReadOnlyPaymentViewSet):
                 'user_pk': balance.user.id
             }
         )
-        
+
         if serializer.is_valid():
             result = serializer.save()
             return Response(result)
-        
+
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
-    
+
     @action(detail=True, methods=['post'])
     def transfer_funds(self, request, pk=None):
         """
@@ -125,25 +124,25 @@ class UserBalanceViewSet(ReadOnlyPaymentViewSet):
         POST /api/balances/{id}/transfer_funds/
         """
         balance = self.get_object()
-        
+
         # Permission check
         if not request.user.is_staff and balance.user != request.user:
             return Response(
                 {'error': 'You can only transfer from your own balance'},
                 status=status.HTTP_403_FORBIDDEN
             )
-        
+
         serializer = FundsTransferSerializer(
             data=request.data,
             context=self.get_serializer_context()
         )
-        
+
         if serializer.is_valid():
             result = serializer.save()
             return Response(result)
-        
+
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
-    
+
     @action(detail=False, methods=['get'])
     def analytics(self, request):
         """
@@ -152,13 +151,13 @@ class UserBalanceViewSet(ReadOnlyPaymentViewSet):
         GET /api/balances/analytics/?days=30
         """
         serializer = BalanceStatsSerializer(data=request.query_params)
-        
+
         if serializer.is_valid():
             result = serializer.save()
             return Response(result)
-        
+
         return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)
-    
+
     @action(detail=False, methods=['get'])
     def summary(self, request):
         """
@@ -168,7 +167,7 @@ class UserBalanceViewSet(ReadOnlyPaymentViewSet):
         """
         try:
             queryset = self.filter_queryset(self.get_queryset())
-            
+
             summary = queryset.aggregate(
                 total_users=models.Count('id'),
                 total_balance=models.Sum('balance_usd'),
@@ -182,7 +181,7 @@ class UserBalanceViewSet(ReadOnlyPaymentViewSet):
                     filter=models.Q(balance_usd=0)
                 ),
             )
-            
+
             return Response({
                 'summary': {
                     **summary,
@@ -191,7 +190,7 @@ class UserBalanceViewSet(ReadOnlyPaymentViewSet):
                 },
                 'generated_at': timezone.now().isoformat()
             })
-            
+
         except Exception as e:
             logger.error(f"Balance summary failed: {e}")
             return Response(
@@ -206,24 +205,24 @@ class TransactionViewSet(ReadOnlyPaymentViewSet):
     
     Read-only access to transaction history with filtering.
     """
-    
+
     queryset = Transaction.objects.all()
     serializer_class = TransactionSerializer
     permission_classes = [permissions.IsAuthenticated]
     filterset_fields = ['user', 'transaction_type', 'payment_id']
     search_fields = ['description', 'payment_id']
     ordering_fields = ['created_at', 'amount']
-    
+
     def get_queryset(self):
         """Filter by user permissions and optimize queryset."""
         queryset = super().get_queryset().select_related('user')
-        
+
         # Non-staff users can only see their own transactions
         if not self.request.user.is_staff:
             queryset = queryset.filter(user=self.request.user)
-        
+
         return queryset
-    
+
     @action(detail=False, methods=['get'])
     def by_type(self, request):
         """
@@ -233,14 +232,14 @@ class TransactionViewSet(ReadOnlyPaymentViewSet):
         """
         try:
             queryset = self.filter_queryset(self.get_queryset())
-            
+
             type_stats = {}
             for type_choice in Transaction.TransactionType.choices:
                 type_code = type_choice[0]
                 type_name = type_choice[1]
-                
+
                 type_transactions = queryset.filter(transaction_type=type_code)
-                
+
                 type_stats[type_code] = {
                     'name': type_name,
                     'total_transactions': type_transactions.count(),
@@ -255,19 +254,19 @@ class TransactionViewSet(ReadOnlyPaymentViewSet):
                         )['avg'] or 0
                     ),
                 }
-            
+
             return Response({
                 'type_stats': type_stats,
                 'generated_at': timezone.now().isoformat()
             })
-            
+
         except Exception as e:
             logger.error(f"Transaction type stats failed: {e}")
             return Response(
                 {'error': f'Type stats failed: {e}'},
                 status=status.HTTP_500_INTERNAL_SERVER_ERROR
             )
-    
+
     @action(detail=False, methods=['get'])
     def recent(self, request):
         """
@@ -278,19 +277,19 @@ class TransactionViewSet(ReadOnlyPaymentViewSet):
         try:
             limit = int(request.query_params.get('limit', 10))
             limit = min(limit, 100)  # Cap at 100
-            
+
             queryset = self.filter_queryset(self.get_queryset())
             recent_transactions = queryset.order_by('-created_at')[:limit]
-            
+
             serializer = self.get_serializer(recent_transactions, many=True)
-            
+
             return Response({
                 'transactions': serializer.data,
                 'count': len(serializer.data),
                 'limit': limit,
                 'generated_at': timezone.now().isoformat()
             })
-            
+
         except Exception as e:
             logger.error(f"Recent transactions failed: {e}")
             return Response(
@@ -305,33 +304,33 @@ class UserTransactionViewSet(NestedPaymentViewSet):
     
     User-scoped access to transaction history.
     """
-    
+
     queryset = Transaction.objects.all()
     serializer_class = TransactionSerializer
     permission_classes = [permissions.IsAuthenticated]
     filterset_fields = ['transaction_type', 'payment_id']
     search_fields = ['description', 'payment_id']
     ordering_fields = ['created_at', 'amount']
-    
+
     # Nested ViewSet configuration
     parent_lookup_field = 'user_pk'
     parent_model_field = 'user'
-    
+
     # Read-only operations only
     http_method_names = ['get', 'head', 'options']
-    
+
     def get_queryset(self):
         """Filter by user and optimize queryset."""
         queryset = super().get_queryset()
-        
+
         # Additional permission check: users can only see their own transactions
         if not self.request.user.is_staff:
             user_id = self.kwargs.get('user_pk')
             if str(self.request.user.id) != str(user_id):
                 return queryset.none()
-        
+
         return queryset
-    
+
     @action(detail=False, methods=['get'])
     def summary(self, request, user_pk=None):
         """
@@ -341,7 +340,7 @@ class UserTransactionViewSet(NestedPaymentViewSet):
         """
         try:
             queryset = self.filter_queryset(self.get_queryset())
-            
+
             summary = queryset.aggregate(
                 total_transactions=models.Count('id'),
                 total_credits=models.Sum(
@@ -354,14 +353,14 @@ class UserTransactionViewSet(NestedPaymentViewSet):
                 ),
                 net_amount=models.Sum('amount_usd'),
             )
-            
+
             # Get type breakdown
             type_breakdown = dict(
                 queryset.values('transaction_type')
                 .annotate(count=models.Count('id'))
                 .values_list('transaction_type', 'count')
             )
-            
+
             return Response({
                 'user_id': user_pk,
                 'summary': {
@@ -373,7 +372,7 @@ class UserTransactionViewSet(NestedPaymentViewSet):
                 },
                 'generated_at': timezone.now().isoformat()
             })
-            
+
         except Exception as e:
             logger.error(f"User transaction summary failed: {e}")
             return Response(
