@@ -4,13 +4,14 @@ API Key serializers for the Universal Payment System v2.0.
 DRF serializers for API key operations with service integration.
 """
 
-from rest_framework import serializers
-from typing import Dict, Any
+from typing import Any, Dict
+
 from django.contrib.auth import get_user_model
-from drf_spectacular.utils import extend_schema_serializer, extend_schema_field, OpenApiTypes
+from rest_framework import serializers
+
+from django_cfg.modules.django_logging import get_logger
 
 from ...models import APIKey
-from django_cfg.modules.django_logging import get_logger
 
 User = get_user_model()
 logger = get_logger("api_key_serializers")
@@ -22,11 +23,11 @@ class APIKeyListSerializer(serializers.ModelSerializer):
     
     Optimized for API key lists with minimal data (no key value).
     """
-    
+
     user = serializers.StringRelatedField(read_only=True)
     is_expired = serializers.BooleanField(read_only=True)
     is_valid = serializers.BooleanField(read_only=True)
-    
+
     class Meta:
         model = APIKey
         fields = [
@@ -83,7 +84,7 @@ class APIKeyCreateSerializer(serializers.Serializer):
     
     Creates new API keys and returns the full key value (only once).
     """
-    
+
     name = serializers.CharField(
         max_length=100,
         help_text="Descriptive name for the API key"
@@ -95,38 +96,38 @@ class APIKeyCreateSerializer(serializers.Serializer):
         max_value=365,
         help_text="Expiration in days (optional, null for no expiration)"
     )
-    
+
     def validate_name(self, value: str) -> str:
         """Validate API key name is unique for user."""
         user = self.context['request'].user
         user_id = self.context.get('user_pk', user.id)
-        
+
         if APIKey.objects.filter(user_id=user_id, name=value).exists():
             raise serializers.ValidationError(f"API key with name '{value}' already exists")
-        
+
         return value
-    
+
     def create(self, validated_data: Dict[str, Any]) -> APIKey:
         """Create API key using APIKey manager."""
         try:
             user = self.context['request'].user
             user_id = self.context.get('user_pk', user.id)
-            
+
             # Get user object if creating for different user (admin only)
             if str(user_id) != str(user.id):
                 if not user.is_staff:
                     raise serializers.ValidationError("Only staff can create API keys for other users")
                 user = User.objects.get(id=user_id)
-            
+
             # Create API key using manager
             api_key = APIKey.create_for_user(
                 user=user,
                 name=validated_data['name'],
                 expires_in_days=validated_data.get('expires_in_days')
             )
-            
+
             if api_key:
-                logger.info(f"API key created successfully", extra={
+                logger.info("API key created successfully", extra={
                     'api_key_id': str(api_key.id),
                     'user_id': user.id,
                     'name': validated_data['name']
@@ -134,21 +135,21 @@ class APIKeyCreateSerializer(serializers.Serializer):
                 return api_key
             else:
                 raise serializers.ValidationError("Failed to create API key")
-                
+
         except User.DoesNotExist:
             raise serializers.ValidationError(f"User {user_id} not found")
         except Exception as e:
             logger.error(f"API key creation error: {e}")
             raise serializers.ValidationError(f"API key creation failed: {e}")
-    
+
     def to_representation(self, instance: APIKey) -> Dict[str, Any]:
         """Return API key data with full key value (only on creation)."""
         data = APIKeyDetailSerializer(instance, context=self.context).data
-        
+
         # Add full key value only on creation (security: shown only once)
         data['key'] = instance.key
         data['warning'] = "This is the only time the full API key will be shown. Please save it securely."
-        
+
         return data
 
 
@@ -158,46 +159,46 @@ class APIKeyUpdateSerializer(serializers.ModelSerializer):
     
     Allows updating name and active status only.
     """
-    
+
     class Meta:
         model = APIKey
         fields = ['name', 'is_active']
-    
+
     def validate_name(self, value: str) -> str:
         """Validate API key name is unique for user."""
         user_id = self.instance.user_id
-        
+
         # Check if another API key with same name exists for this user
         existing = APIKey.objects.filter(
             user_id=user_id,
             name=value
         ).exclude(id=self.instance.id)
-        
+
         if existing.exists():
             raise serializers.ValidationError(f"API key with name '{value}' already exists")
-        
+
         return value
-    
+
     def update(self, instance: APIKey, validated_data: Dict[str, Any]) -> APIKey:
         """Update API key with logging."""
         old_name = instance.name
         old_active = instance.is_active
-        
+
         instance = super().update(instance, validated_data)
-        
+
         # Log changes
         changes = []
         if instance.name != old_name:
             changes.append(f"name: {old_name} → {instance.name}")
         if instance.is_active != old_active:
             changes.append(f"active: {old_active} → {instance.is_active}")
-        
+
         if changes:
             logger.info(f"API key updated: {', '.join(changes)}", extra={
                 'api_key_id': str(instance.id),
                 'user_id': instance.user_id
             })
-        
+
         return instance
 
 
@@ -207,7 +208,7 @@ class APIKeyActionSerializer(serializers.Serializer):
     
     Handles deactivation, extension, and usage increment.
     """
-    
+
     action = serializers.ChoiceField(
         choices=[
             ('deactivate', 'Deactivate'),
@@ -233,48 +234,48 @@ class APIKeyActionSerializer(serializers.Serializer):
         allow_null=True,
         help_text="IP address for usage tracking"
     )
-    
+
     def validate(self, attrs: Dict[str, Any]) -> Dict[str, Any]:
         """Validate action-specific requirements."""
         action = attrs.get('action')
-        
+
         if action == 'extend' and not attrs.get('days'):
             raise serializers.ValidationError("days is required for extend action")
-        
+
         return attrs
-    
+
     def save(self) -> Dict[str, Any]:
         """Perform API key action."""
         try:
             api_key_id = self.context.get('api_key_id')
             if not api_key_id:
                 raise serializers.ValidationError("API key ID is required")
-            
+
             api_key = APIKey.objects.get(id=api_key_id)
             action = self.validated_data['action']
-            
+
             if action == 'deactivate':
                 reason = self.validated_data.get('reason')
                 success = api_key.deactivate(reason=reason)
-                message = f"API key deactivated successfully"
-                
+                message = "API key deactivated successfully"
+
             elif action == 'extend':
                 days = self.validated_data['days']
                 success = api_key.extend_expiry(days=days)
                 message = f"API key expiration extended by {days} days"
-                
+
             elif action == 'increment_usage':
                 ip_address = self.validated_data.get('ip_address')
                 success = api_key.increment_usage(ip_address=ip_address)
-                message = f"API key usage incremented"
-                
+                message = "API key usage incremented"
+
             else:
                 raise serializers.ValidationError(f"Unknown action: {action}")
-            
+
             if success:
                 # Refresh from database
                 api_key.refresh_from_db()
-                
+
                 return {
                     'success': True,
                     'message': message,
@@ -286,7 +287,7 @@ class APIKeyActionSerializer(serializers.Serializer):
                     'error': f"Failed to {action} API key",
                     'error_code': f'{action}_failed'
                 }
-                
+
         except APIKey.DoesNotExist:
             return {
                 'success': False,
@@ -308,25 +309,25 @@ class APIKeyValidationSerializer(serializers.Serializer):
     
     Validates API key and returns key information.
     """
-    
+
     key = serializers.CharField(
         min_length=32,
         max_length=64,
         help_text="API key to validate"
     )
-    
+
     def validate_key(self, value: str) -> str:
         """Validate API key format."""
         if not value.startswith('pk_'):
             raise serializers.ValidationError("Invalid API key format")
         return value
-    
+
     def save(self) -> Dict[str, Any]:
         """Validate API key and return information."""
         try:
             key_value = self.validated_data['key']
             api_key = APIKey.get_valid_key(key_value)
-            
+
             if api_key:
                 return {
                     'success': True,
@@ -341,7 +342,7 @@ class APIKeyValidationSerializer(serializers.Serializer):
                     'api_key': None,
                     'message': 'API key is invalid or expired'
                 }
-                
+
         except Exception as e:
             logger.error(f"API key validation error: {e}")
             return {
@@ -371,31 +372,32 @@ class APIKeyStatsSerializer(serializers.Serializer):
     
     Used for API key analytics and reporting.
     """
-    
+
     days = serializers.IntegerField(
         default=30,
         min_value=1,
         max_value=365,
         help_text="Number of days to analyze"
     )
-    
+
     def save(self) -> Dict[str, Any]:
         """Get API key statistics."""
         try:
+            from datetime import timedelta
+
             from django.db import models
             from django.utils import timezone
-            from datetime import timedelta
-            
+
             days = self.validated_data['days']
             since_date = timezone.now() - timedelta(days=days)
-            
+
             # Get user-specific stats if user context provided
             user_id = self.context.get('user_pk')
             if user_id:
                 queryset = APIKey.objects.filter(user_id=user_id)
             else:
                 queryset = APIKey.objects.all()
-            
+
             stats = queryset.aggregate(
                 total_keys=models.Count('id'),
                 active_keys=models.Count('id', filter=models.Q(is_active=True)),
@@ -406,7 +408,7 @@ class APIKeyStatsSerializer(serializers.Serializer):
                     filter=models.Q(last_used_at__gte=since_date)
                 ),
             )
-            
+
             return {
                 'success': True,
                 'stats': {
@@ -418,7 +420,7 @@ class APIKeyStatsSerializer(serializers.Serializer):
                 'period_days': days,
                 'generated_at': timezone.now().isoformat()
             }
-            
+
         except Exception as e:
             logger.error(f"API key stats error: {e}")
             return {
