@@ -47,7 +47,7 @@ class CurrencySerializer(serializers.ModelSerializer):
 class CurrencyListSerializer(serializers.ModelSerializer):
     """
     Lightweight currency serializer for lists.
-    
+
     Optimized for currency selection and lists.
     """
 
@@ -63,6 +63,8 @@ class CurrencyListSerializer(serializers.ModelSerializer):
             'currency_type',
             'type_display',
             'is_active',
+            'usd_rate',
+            'usd_rate_updated_at',
         ]
         read_only_fields = fields
 
@@ -70,11 +72,11 @@ class CurrencyListSerializer(serializers.ModelSerializer):
 class NetworkSerializer(serializers.ModelSerializer):
     """
     Network serializer for blockchain networks.
-    
+
     Used for network information and selection.
     """
 
-    currency = CurrencyListSerializer(read_only=True)
+    currency = CurrencyListSerializer(read_only=True, allow_null=True, required=False)
 
     class Meta:
         model = Network
@@ -93,12 +95,12 @@ class NetworkSerializer(serializers.ModelSerializer):
 class ProviderCurrencySerializer(serializers.ModelSerializer):
     """
     Provider currency serializer for provider-specific currency info.
-    
+
     Used for provider currency management and rates.
     """
 
     currency = CurrencyListSerializer(read_only=True)
-    network = NetworkSerializer(read_only=True)
+    network = NetworkSerializer(read_only=True, allow_null=True, required=False)
 
     class Meta:
         model = ProviderCurrency
