@@ -51,13 +51,16 @@ class PaymentListSerializer(serializers.ModelSerializer):
 class PaymentSerializer(serializers.ModelSerializer):
     """
     Complete payment serializer with full details.
-    
+
     Used for detail views and updates.
     """
 
     user = serializers.StringRelatedField(read_only=True)
+    currency = serializers.CharField(source='currency.code', read_only=True)
+    network = serializers.CharField(source='network.name', read_only=True, allow_null=True)
     status_display = serializers.CharField(source='get_status_display', read_only=True)
     amount_display = serializers.SerializerMethodField(read_only=True)
+    amount_crypto = serializers.SerializerMethodField(read_only=True)
 
     # Status check methods
     is_pending = serializers.SerializerMethodField(read_only=True)
@@ -69,6 +72,22 @@ class PaymentSerializer(serializers.ModelSerializer):
         """Get formatted amount display."""
         return f"${obj.amount_usd:.2f}"
 
+    def get_amount_crypto(self, obj) -> float:
+        """Calculate crypto amount from USD amount and currency rate."""
+        try:
+            from ...models import Currency
+
+            # Get currency by code
+            currency = Currency.objects.filter(code=obj.currency, is_active=True).first()
+
+            if currency and currency.usd_rate and currency.usd_rate > 0:
+                return obj.amount_usd / currency.usd_rate
+
+            return 0.0
+        except Exception as e:
+            logger.error(f"Failed to calculate crypto amount: {e}")
+            return 0.0
+
     def get_is_pending(self, obj) -> bool:
         """Check if payment is pending."""
         return obj.status == obj.PaymentStatus.PENDING
@@ -91,6 +110,7 @@ class PaymentSerializer(serializers.ModelSerializer):
             'id',
             'user',
             'amount_usd',
+            'amount_crypto',
             'currency',
             'network',
             'provider',
@@ -118,6 +138,7 @@ class PaymentSerializer(serializers.ModelSerializer):
         read_only_fields = [
             'id',
             'user',
+            'amount_crypto',
             'provider_payment_id',
             'payment_url',
             'pay_address',
@@ -147,23 +168,9 @@ class PaymentCreateSerializer(serializers.Serializer):
         max_value=50000.0,
         help_text="Amount in USD (1.00 - 50,000.00)"
     )
-    currency_code = serializers.ChoiceField(
-        choices=[
-            ('BTC', 'Bitcoin'),
-            ('ETH', 'Ethereum'),
-            ('LTC', 'Litecoin'),
-            ('XMR', 'Monero'),
-            ('USDT', 'Tether'),
-            ('USDC', 'USD Coin'),
-            ('ADA', 'Cardano'),
-            ('DOT', 'Polkadot'),
-        ],
-        help_text="Cryptocurrency to receive"
-    )
-    provider = serializers.ChoiceField(
-        choices=[('nowpayments', 'NowPayments')],
-        default='nowpayments',
-        help_text="Payment provider"
+    currency_code = serializers.CharField(
+        max_length=10,
+        help_text="Cryptocurrency code (validated against active currencies)"
     )
     callback_url = serializers.URLField(
         required=False,
