@@ -236,7 +236,11 @@ class DjangoConfig(BaseModel):
 
     ssl_redirect: Optional[bool] = Field(
         default=None,
-        description="Force SSL redirect on/off (None = auto based on domains and environment)",
+        description=(
+            "Force SSL redirect (SECURE_SSL_REDIRECT). "
+            "None (default) = disabled (assumes reverse proxy handles SSL termination). "
+            "Set to True only if Django handles SSL directly (rare: bare metal without proxy)."
+        ),
     )
 
     # === CORS Configuration ===
