@@ -4,14 +4,14 @@ Integration generators module.
 Contains generators for third-party integrations and frameworks:
 - Session configuration
 - External services (Telegram, Unfold, Constance)
-- API frameworks (JWT, DRF, Spectacular, Revolution)
+- API frameworks (JWT, DRF, Spectacular, OpenAPI Client)
 - Background tasks (Dramatiq)
 """
 
-from .sessions import SessionSettingsGenerator
-from .third_party import ThirdPartyIntegrationsGenerator
 from .api import APIFrameworksGenerator
+from .sessions import SessionSettingsGenerator
 from .tasks import TasksSettingsGenerator
+from .third_party import ThirdPartyIntegrationsGenerator
 
 __all__ = [
     "SessionSettingsGenerator",
