@@ -124,10 +124,14 @@ class TelegramConfig(BaseModel):
     @field_validator('webhook_url')
     @classmethod
     def validate_webhook_url(cls, v: Optional[str]) -> Optional[str]:
-        """Validate webhook URL format."""
+        """Validate webhook URL format. Allows environment variable templates like ${VAR:-default}."""
         if v is None:
             return v
 
+        # Skip validation for environment variable templates
+        if v.startswith("${") and "}" in v:
+            return v
+
         if not v.startswith('https://'):
             raise ValueError("Webhook URL must use HTTPS")
 
