@@ -4,29 +4,44 @@ Unfold Models Package
 All Pydantic models for Django Unfold admin interface.
 """
 
-from .config import UnfoldConfig, UnfoldTheme, UnfoldColors, UnfoldSidebar, UnfoldThemeConfig, UnfoldDashboardConfig
-from .navigation import NavigationItem, NavigationSection, NavigationItemType
+from .config import (
+    UnfoldColors,
+    UnfoldConfig,
+    UnfoldDashboardConfig,
+    UnfoldSidebar,
+    UnfoldTheme,
+    UnfoldThemeConfig,
+)
+from .dashboard import (
+    ChartData,
+    ChartDataset,
+    DashboardData,
+    DashboardWidget,
+    QuickAction,
+    StatCard,
+    SystemHealthItem,
+)
 from .dropdown import SiteDropdownItem
-from .dashboard import StatCard, SystemHealthItem, QuickAction, DashboardWidget, DashboardData, ChartDataset, ChartData
+from .navigation import NavigationItem, NavigationItemType, NavigationSection
 from .tabs import TabConfiguration, TabItem
 
 __all__ = [
     # Config models
     'UnfoldConfig',
-    'UnfoldTheme', 
+    'UnfoldTheme',
     'UnfoldColors',
     'UnfoldSidebar',
     'UnfoldThemeConfig',
     'UnfoldDashboardConfig',
-    
+
     # Navigation models
     'NavigationItem',
     'NavigationSection',
     'NavigationItemType',
-    
+
     # Dropdown models
     'SiteDropdownItem',
-    
+
     # Dashboard models
     'StatCard',
     'SystemHealthItem',
@@ -35,7 +50,7 @@ __all__ = [
     'DashboardData',
     'ChartDataset',
     'ChartData',
-    
+
     # Tab models
     'TabConfiguration',
     'TabItem',
