@@ -10,8 +10,8 @@ MODULES_REGISTRY = {
     # Configuration utilities
     "set_current_config": ("django_cfg.core.config", "set_current_config"),
 
-    # RPC Client module
-    "DjangoCfgRPCConfig": ("django_cfg.modules.django_ipc_client.config", "DjangoCfgRPCConfig"),
+    # IPC/RPC module
+    "DjangoCfgRPCConfig": ("django_cfg.apps.ipc", "DjangoCfgRPCConfig"),
 
     # Import/Export integration (simple re-exports)
     "ImportForm": ("django_cfg.modules.django_import_export", "ImportForm"),
